from typing import TypedDict

class BasketballCourtSettings(TypedDict):
    background_color: str
    court_color: str
    paint_color: str
    three_points_color: str
    lines_color: str
    side_paint_color: str
    lines_width: int
